@@ -29,11 +29,10 @@ renv_cellar_database <- function(project = NULL) {
   rest <- map_chr(parts, `[[`, 2L)
   version <- sub(extpat, "", rest)
 
-  data.frame(
+  data_frame(
     Package = package,
     Version = version,
-    Path    = paths,
-    stringsAsFactors = FALSE
+    Path    = paths
   )
 
 }
