@@ -24,7 +24,7 @@ deactivate <- function(project = NULL) {
   renv_scope_error_handler()
 
   project <- renv_project_resolve(project)
-  renv_scope_lock(project = project)
+  renv_project_lock(project = project)
 
   renv_infrastructure_remove_rprofile(project)
 
