@@ -20,7 +20,7 @@ renv_description_read <- function(path = NULL,
 
   # read value with filebacked cache
   description <- filebacked(
-    scope    = "DESCRIPTION",
+    scope    = "renv_description_read",
     path     = path,
     callback = renv_description_read_impl,
     subdir   = subdir,
@@ -137,11 +137,10 @@ renv_description_parse_field <- function(field) {
   if (empty(matches))
     return(NULL)
 
-  data.frame(
+  data_frame(
     Package = extract_chr(matches, 2L),
     Require = extract_chr(matches, 3L),
-    Version = extract_chr(matches, 4L),
-    stringsAsFactors = FALSE
+    Version = extract_chr(matches, 4L)
   )
 
 }
