@@ -1,6 +1,6 @@
 
 renv_extsoft_curl_version <- function() {
-  "7.70.0"
+  Sys.getenv("RENV_EXTSOFT_CURL_VERSION", unset = "7.77.0")
 }
 
 renv_extsoft_install <- function(quiet = FALSE) {
@@ -34,13 +34,13 @@ renv_extsoft_install <- function(quiet = FALSE) {
     renv_pretty_print(
       files,
       "The following external software tools will be installed:",
-      sprintf("Tools will be installed into '%s'.", aliased_path(extsoft)),
+      sprintf("Tools will be installed into %s.", renv_path_pretty(extsoft)),
       wrap = FALSE
     )
 
     if (!proceed()) {
       renv_report_user_cancel()
-      return(FALSE)
+      invokeRestart("abort")
     }
 
   }
@@ -49,7 +49,7 @@ renv_extsoft_install <- function(quiet = FALSE) {
 
     # download the file
     url <- file.path(root, file)
-    destfile <- renv_tempfile_path("renv-archive-", fileext = ".zip")
+    destfile <- renv_scope_tempfile("renv-archive-", fileext = ".zip")
     download(url, destfile = destfile, quiet = quiet)
 
     # write manifest
@@ -148,7 +148,7 @@ renv_extsoft_use <- function(quiet = FALSE) {
 
     if (!proceed()) {
       renv_report_user_cancel()
-      return(FALSE)
+      invokeRestart("abort")
     }
 
   }
