@@ -20,18 +20,18 @@ history <- function(project = NULL) {
   renv_scope_error_handler()
 
   project <- renv_project_resolve(project)
-  renv_scope_lock(project = project)
+  renv_project_lock(project = project)
 
   lockpath <- renv_lockfile_path(project)
   if (!file.exists(lockpath))
-    return(data.frame())
+    return(data_frame())
 
   renv_git_preflight()
 
   owd <- setwd(project)
   on.exit(setwd(owd), add = TRUE)
 
-  args <- c("log", "--pretty=format:%H\031%at\031%ct\031%s", shQuote(lockpath))
+  args <- c("log", "--pretty=format:%H\031%at\031%ct\031%s", renv_shell_path(lockpath))
   data <- renv_system_exec("git", args, action = "retrieving git log")
 
   parts <- strsplit(data, "\031", fixed = TRUE)
@@ -67,7 +67,7 @@ revert <- function(commit = "HEAD", ..., project = NULL) {
   renv_dots_check(...)
 
   project <- renv_project_resolve(project)
-  renv_scope_lock(project = project)
+  renv_project_lock(project = project)
 
   renv_git_preflight()
 
@@ -75,9 +75,9 @@ revert <- function(commit = "HEAD", ..., project = NULL) {
   on.exit(setwd(owd), add = TRUE)
 
   lockpath <- renv_lockfile_path(project = project)
-  system2("git", c("checkout", commit, "--", shQuote(lockpath)))
-  system2("git", c("reset", "HEAD", shQuote(lockpath)), stdout = FALSE, stderr = FALSE)
-  system2("git", c("diff", "--", shQuote(lockpath)))
+  system2("git", c("checkout", commit, "--", renv_shell_path(lockpath)))
+  system2("git", c("reset", "HEAD", renv_shell_path(lockpath)), stdout = FALSE, stderr = FALSE)
+  system2("git", c("diff", "--", renv_shell_path(lockpath)))
 
   vwritef("* renv.lock from commit %s has been checked out.", commit)
   invisible(commit)
