@@ -92,22 +92,6 @@ renv_lockfile_api <- function(lockfile = NULL) {
 
 }
 
-#' @export
-print.renv_lockfile_api <- function(x, ...) {
-  lockfile <- x$data()
-  records <- renv_records(lockfile)
-  n <- length(records)
-  fmt <- "A lockfile containing %s."
-  msg <- sprintf(fmt, nplural("package record", n))
-  writeLines(msg)
-}
-
-#' @export
-str.renv_lockfile_api <- function(object, ...) {
-  lockfile <- object$data()
-  str(lockfile)
-}
-
 #' Programmatically Create and Modify a Lockfile
 #'
 #' This function provides an API for creating and modifying `renv` lockfiles.
