@@ -21,9 +21,19 @@ renv_remotes_resolve <- function(spec, latest = FALSE) {
   if (is.null(spec) || is.list(spec))
     return(spec)
 
-  # check for URLs
-  if (grepl("^(?:file|https?)://", spec))
-    return(renv_remotes_resolve_url(spec, quiet = TRUE))
+  # remove a trailing slash
+  # https://github.com/rstudio/renv/issues/1135
+  spec <- gsub("/+$", "", spec, perl = TRUE)
+
+  # check for archive URLs -- this is a bit hacky
+  if (grepl("^(?:file|https?)://", spec)) {
+    for (suffix in c(".zip", ".tar.gz", ".tgz", "/tarball"))
+      if (endswith(spec, suffix))
+        return(renv_remotes_resolve_url(spec, quiet = TRUE))
+  }
+
+  # remove github prefix
+  spec <- gsub("^https?://(?:www\\.)?github\\.com/", "", spec)
 
   # check for paths to existing local files
   first <- substring(spec, 1L, 1L)
@@ -102,10 +112,10 @@ renv_remotes_parse_impl <- function(spec, pattern, fields, perl = FALSE) {
 renv_remotes_parse_repos <- function(spec) {
 
   pattern <- paste0(
-    "^",                               # start
-    "(?:([^:]+)::)?",                  # optional repository name
-    "([[:alnum:].]+)",                 # package name
-    "(?:@([[:digit:]_.-]+))?",         # optional package version
+    "^",                                           # start
+    "(?:([^:]+)::)?",                              # optional repository name
+    "([[:alnum:].]+)",                             # package name
+    "(?:@([[:digit:]_.-]+))?",                     # optional package version
     "$"
   )
 
@@ -118,18 +128,23 @@ renv_remotes_parse_remote <- function(spec) {
 
   pattern <- paste0(
     "^",
-    "(?:([^@:]+)(?:@([^:]+))?::)?",    # optional prefix, providing type + host
-    "([^/#@:]+)",                      # a username
-    "(?:/([^@#:]+))?",                 # a repository (allow sub-repositories)
-    "(?::([^@#:]+))?",                 # optional subdirectory
-    "(?:#([^@#:]+))?",                 # optional hash (e.g. pull request)
-    "(?:@([^@#:]+))?",                 # optional ref (e.g. branch or commit)
+    "(?:([[:alpha:]][[:alnum:].]*[[:alnum:]])=)?",  # optional package name
+    "(?:([^@:]+)(?:@([^:]+))?::)?",                 # optional prefix, providing type + host
+    "([^/#@:]+)",                                   # a username
+    "(?:/([^@#:]+))?",                              # a repository (allow sub-repositories)
+    "(?::([^@#:]+))?",                              # optional subdirectory
+    "(?:#([^@#:]+))?",                              # optional hash (e.g. pull request)
+    "(?:@([^@#:]+))?",                              # optional ref (e.g. branch or commit)
     "$"
   )
 
-  fields <- c("spec", "type", "host", "user", "repo", "subdir", "pull", "ref")
-  remote <- renv_remotes_parse_impl(spec, pattern, fields)
+  fields <- c(
+    "spec", "package", "type",
+    "host", "user", "repo",
+    "subdir", "pull", "ref"
+  )
 
+  remote <- renv_remotes_parse_impl(spec, pattern, fields)
   if (!nzchar(remote$repo))
     stopf("'%s' is not a valid remote", spec)
 
@@ -137,6 +152,38 @@ renv_remotes_parse_remote <- function(spec) {
 
 }
 
+renv_remotes_parse_gitssh <- function(spec) {
+
+  pattern <- paste0(
+    "^",
+    "(?:([[:alpha:]][[:alnum:].]*[[:alnum:]])=)?",  # optional package name
+    "(?:(git)::)?",                                 # optional git prefix
+    "(",                                            # url start
+      "([^@]+)@",                                   # user (typically, 'git')
+      "([^:]+):",                                   # host
+      "([^:#@]+)",                                  # the rest of the repo url
+    ")",                                            # url end
+    "(?::([^@#:]+))?",                              # optional sub-directory
+    "(?:#([^@#:]+))?",                              # optional hash (e.g. pull request)
+    "(?:@([^@#:]+))?",                              # optional ref (e.g. branch or commit)
+    "$"
+  )
+
+  fields <- c(
+    "spec", "package", "type", "url",
+    "user", "host", "repo",
+    "subdir", "pull", "ref"
+  )
+
+  remote <- renv_remotes_parse_impl(spec, pattern, fields, perl = TRUE)
+  if (!nzchar(remote$repo))
+    stopf("'%s' is not a valid remote", spec)
+
+  remote$type <- remote$type %||% "git"
+  renv_remotes_parse_finalize(remote)
+
+}
+
 renv_remotes_parse_git <- function(spec) {
 
   hostpattern <- paste0(
@@ -149,30 +196,26 @@ renv_remotes_parse_git <- function(spec) {
 
   pattern <- paste0(
     "^",
-    "(?:(git)::)?",                 # optional git prefix
-    "(",                            # URL start
-      "(?:(https?|git|ssh)://)?",     # protocol
-      "(?:([^@]+)@)?",                # login (probably git)
-      hostpattern,                    # host
-      "[/:]([\\w_.-]+)",              # a username
-      "(?:/([^@#:]+?))?",             # a repository (allow sub-repositories)
-      "(?:\\.(git))?",                # optional .git extension
-    ")",                            # URL end
-    "(?::([^@#:]+))?",              # optional sub-directory
-    "(?:#([^@#:]+))?",              # optional hash (e.g. pull request)
-    "(?:@([^@#:]+))?",              # optional ref (e.g. branch or commit)
+    "(?:([[:alpha:]][[:alnum:].]*[[:alnum:]])=)?",  # optional package name
+    "(?:(git)::)?",                                 # optional git prefix
+    "(",                                            # URL start
+      "(?:(https?|git|ssh)://)?",                   #   protocol
+      "(?:([^@]+)@)?",                              #   login (probably git)
+      hostpattern,                                  #   host
+      "[/:]([\\w_.-]+)",                            #   a username
+      "(?:/([^@#:]+?))?",                           #   a repository (allow sub-repositories)
+      "(?:\\.(git))?",                              #   optional .git extension
+    ")",                                            # URL end
+    "(?::([^@#:]+))?",                              # optional sub-directory
+    "(?:#([^@#:]+))?",                              # optional hash (e.g. pull request)
+    "(?:@([^@#:]+))?",                              # optional ref (e.g. branch or commit)
     "$"
   )
 
   fields <- c(
-    "spec",
-      "type",
-      "url",
-        "protocol", "login", "host",
-        "user", "repo", "ext",
-      "subdir",
-      "pull",
-      "ref"
+    "spec", "package", "type",
+    "url", "protocol", "login", "host", "user", "repo", "ext",
+    "subdir", "pull", "ref"
   )
 
   remote <- renv_remotes_parse_impl(spec, pattern, fields, perl = TRUE)
@@ -182,7 +225,7 @@ renv_remotes_parse_git <- function(spec) {
   # If type has not been found & repo looks like a git repo, set it as git
   # (note that this parser also accepts entries which are not truly git
   # references, so we try to "fix up" after the fact)
-  if ("git" %in% c(remote$type, remote$ext, remote$protocol))
+  if ("git" %in% c(remote$login, remote$type, remote$ext, remote$protocol))
     remote$type <- tolower(remote$type %||% "git")
 
   renv_remotes_parse_finalize(remote)
@@ -195,13 +238,14 @@ renv_remotes_parse_url <- function(spec) {
 
   pattern <- paste0(
     "^",
-    "(url)::",              # type (required for URL remotes)
-    "((https?)://([^:]+))", # url, protocol, path
-    "(?::([^@#:]+))?",      # optional subdir
+    "(?:([[:alpha:]][[:alnum:].]*[[:alnum:]])=)?",  # optional package name
+    "(url)::",                                      # type (required for URL remotes)
+    "((https?)://([^:]+))",                         # url, protocol, path
+    "(?::([^@#:]+))?",                              # optional subdir
     "$"
   )
 
-  fields <- c("spec", "type", "url", "protocol", "path", "subdir")
+  fields <- c("spec", "package", "type", "url", "protocol", "path", "subdir")
   remote <- renv_remotes_parse_impl(spec, pattern, fields, perl = TRUE)
   if (!nzchar(remote$url))
     stopf("'%s' is not a valid remote", spec)
@@ -241,9 +285,6 @@ renv_remotes_parse_finalize_github <- function(remote) {
 
 renv_remotes_parse <- function(spec) {
 
-  # https://github.com/rstudio/renv/issues/1064
-  spec <- sub("^[a-zA-Z0-9.]+=", "", spec)
-
   remote <- catch(renv_remotes_parse_repos(spec))
   if (!inherits(remote, "error")) {
     remote$type <- "repository"
@@ -256,6 +297,12 @@ renv_remotes_parse <- function(spec) {
     return(remote)
   }
 
+  remote <- catch(renv_remotes_parse_gitssh(spec))
+  if (!inherits(remote, "error")) {
+    remote$type <- remote$type %||% "git"
+    return(remote)
+  }
+
   remote <- catch(renv_remotes_parse_url(spec))
   if (!inherits(remote, "error")) {
     remote$type <- remote$type %||% "url"
@@ -602,7 +649,7 @@ renv_remotes_resolve_github_release <- function(host, user, repo, spec) {
 
 renv_remotes_resolve_git <- function(remote) {
 
-  package <- remote$repo
+  package <- remote$package %||% basename(remote$repo)
   url     <- remote$url
   subdir  <- remote$subdir
 
