@@ -1,4 +1,8 @@
 
+# controls whether hashes are computed when computing a snapshot
+# can be scoped to FALSE when hashing is not necessary
+`_renv_snapshot_hash` <- TRUE
+
 #' Snapshot a Project
 #'
 #' Call `snapshot()` to create a **lockfile** capturing the state of a project's
@@ -122,7 +126,7 @@ snapshot <- function(project  = NULL,
   renv_snapshot_auto_suppress_next()
 
   project <- renv_project_resolve(project)
-  renv_scope_lock(project = project)
+  renv_project_lock(project = project)
 
   repos <- renv_repos_validate(repos)
   renv_scope_options(repos = repos)
@@ -521,12 +525,21 @@ renv_snapshot_validate_sources <- function(project, lockfile, libpaths) {
 # NOTE: if packages are found in multiple libraries,
 # then the first package found in the library paths is
 # kept and others are discarded
-renv_snapshot_r_packages <- function(libpaths = NULL,
-                                     project  = NULL)
+renv_snapshot_libpaths <- function(libpaths = NULL,
+                                   project  = NULL)
+{
+  dynamic(
+    key   = list(libpaths, project),
+    value = renv_snapshot_libpaths_impl(libpaths, project)
+  )
+}
+
+renv_snapshot_libpaths_impl <- function(libpaths = NULL,
+                                        project  = NULL)
 {
   records <- uapply(
     libpaths,
-    renv_snapshot_r_packages_impl,
+    renv_snapshot_library,
     project = project
   )
 
@@ -534,12 +547,12 @@ renv_snapshot_r_packages <- function(libpaths = NULL,
   records[!dupes]
 }
 
-renv_snapshot_r_packages_impl <- function(library = NULL,
-                                          project = NULL,
-                                          snapshot = TRUE)
+renv_snapshot_library <- function(library = NULL,
+                                  records = TRUE,
+                                  project = NULL)
 {
   # list packages in the library
-  library <- renv_path_normalize(library %||% renv_libpaths_default())
+  library <- renv_path_normalize(library %||% renv_libpaths_active())
   paths <- list.files(library, full.names = TRUE)
 
   # remove 'base' packages
@@ -554,15 +567,15 @@ renv_snapshot_r_packages_impl <- function(library = NULL,
   paths <- paths[grep(pattern, basename(paths))]
 
   # validate the remaining set of packages
-  valid <- renv_snapshot_r_library_diagnose(library, paths)
+  valid <- renv_snapshot_library_diagnose(library, paths)
 
   # remove duplicates (so only first package entry discovered in library wins)
   duplicated <- duplicated(basename(valid))
   packages <- valid[!duplicated]
 
   # early exit if we're just collecting the list of packages
-  if (!snapshot)
-    return(packages)
+  if (!records)
+    return(basename(packages))
 
   # snapshot description files
   descriptions <- file.path(packages, "DESCRIPTION")
@@ -592,17 +605,17 @@ renv_snapshot_r_packages_impl <- function(library = NULL,
 
 }
 
-renv_snapshot_r_library_diagnose <- function(library, pkgs) {
+renv_snapshot_library_diagnose <- function(library, pkgs) {
 
   pkgs <- grep("00LOCK", pkgs, invert = TRUE, value = TRUE)
-  pkgs <- renv_snapshot_r_library_diagnose_broken_link(library, pkgs)
-  pkgs <- renv_snapshot_r_library_diagnose_tempfile(library, pkgs)
-  pkgs <- renv_snapshot_r_library_diagnose_missing_description(library, pkgs)
+  pkgs <- renv_snapshot_library_diagnose_broken_link(library, pkgs)
+  pkgs <- renv_snapshot_library_diagnose_tempfile(library, pkgs)
+  pkgs <- renv_snapshot_library_diagnose_missing_description(library, pkgs)
   pkgs
 
 }
 
-renv_snapshot_r_library_diagnose_broken_link <- function(library, pkgs) {
+renv_snapshot_library_diagnose_broken_link <- function(library, pkgs) {
 
   broken <- !file.exists(pkgs)
   if (!any(broken))
@@ -618,7 +631,7 @@ renv_snapshot_r_library_diagnose_broken_link <- function(library, pkgs) {
 
 }
 
-renv_snapshot_r_library_diagnose_tempfile <- function(library, pkgs) {
+renv_snapshot_library_diagnose_tempfile <- function(library, pkgs) {
 
   names <- basename(pkgs)
   missing <- grepl("^file(?:\\w){12}", names)
@@ -635,7 +648,7 @@ renv_snapshot_r_library_diagnose_tempfile <- function(library, pkgs) {
 
 }
 
-renv_snapshot_r_library_diagnose_missing_description <- function(library, pkgs) {
+renv_snapshot_library_diagnose_missing_description <- function(library, pkgs) {
 
   desc <- file.path(pkgs, "DESCRIPTION")
   missing <- !file.exists(desc)
@@ -684,10 +697,12 @@ renv_snapshot_description_impl <- function(dcf, path = NULL) {
   }
 
   # generate a hash if we can
-  dcf[["Hash"]] <- if (is.null(path))
-    renv_hash_description_impl(dcf)
-  else
-    renv_hash_description(path)
+  dcf[["Hash"]] <- if (`_renv_snapshot_hash`) {
+    if (is.null(path))
+      renv_hash_description_impl(dcf)
+    else
+      renv_hash_description(path)
+  }
 
   # generate a Requirements field -- primarily for use by 'pak'
   fields <- c("Depends", "Imports", "LinkingTo")
@@ -965,10 +980,8 @@ renv_snapshot_filter_explicit <- function(project, records) {
 
   # keep only packages mentioned in the project DESCRIPTION file
   descpath <- file.path(project, "DESCRIPTION")
-  if (!file.exists(descpath)) {
-    fmt <- "%s does not exist; cannot perform explicit snapshot"
-    stopf(fmt, renv_path_pretty(descpath))
-  }
+  if (!file.exists(descpath))
+    return(records["renv"])
 
   # get the requested dependencies
   deps <- renv_snapshot_dependencies(project, descpath)
