@@ -1,6 +1,4 @@
 
-.docker <- FALSE
-
 .onLoad <- function(libname, pkgname) {
   renv_zzz_load()
 }
@@ -9,35 +7,42 @@
   renv_zzz_attach()
 }
 
+.onUnload <- function(libpath) {
+  renv_task_unload()
+}
+
 renv_zzz_load <- function() {
 
+  # registerS3method("[<-", "__renv_dotty__", dotty, envir = .BaseNamespaceEnv)
+
   renv_metadata_init()
   renv_platform_init()
+  renv_binding_init()
+  renv_virtualization_init()
   renv_envvars_init()
   renv_log_init()
   renv_methods_init()
   renv_libpaths_init()
   renv_patch_init()
+  renv_lock_init()
+  renv_sandbox_init()
 
-  # TODO: It's not clear if these callbacks are safe to use when renv is
-  # embedded, but it's unlikely that clients would want them anyhow.
   if (!renv_metadata_embedded()) {
 
-    addTaskCallback(
-      renv_repos_init_callback,
-      name = "renv:::renv_repos_init_callback"
-    )
+    # TODO: It's not clear if these callbacks are safe to use when renv is
+    # embedded, but it's unlikely that clients would want them anyhow.
+    renv_task_create(renv_sandbox_task)
+    renv_task_create(renv_snapshot_task)
 
-    addTaskCallback(
-      renv_snapshot_auto_callback,
-      name = "renv:::renv_snapshot_auto_callback"
+    # pkgload likes to lock all bindings in a package, even if we might
+    # try to unlock those in .onLoad(). Sneak around that.
+    setHook(
+      packageEvent("renv", "onLoad"),
+      renv_binding_init,
     )
 
   }
 
-  # record whether we're in a docker environment
-  assign(".docker", file.exists("/.dockerenv"), envir = renv_envir_self())
-
   # if an renv project already appears to be loaded, then re-activate
   # the sandbox now -- this is primarily done to support suspend and
   # resume with RStudio where the user profile might not be run
