@@ -15,7 +15,22 @@ test_that("packages can be installed, restored from Bioconductor", {
   cran <- "https://cloud.r-project.org"
   install.packages("BiocManager", repos = cran, quiet = TRUE)
   BiocManager <- asNamespace("BiocManager")
-  BiocManager$install("Biobase", quiet = TRUE)
+
+  # TODO: Running this directly from 'renv' seems to fail, at least
+  # on R 4.2-arm64 macOS?
+  local({
+    renv_scope_envvars(R_LIBS = .libPaths()[1])
+
+    lines <- c(
+      sprintf(".libPaths('%s')", .libPaths()[1L]),
+      "options(pkgType = 'source')",
+      "BiocManager::install('Biobase', quiet = TRUE)"
+    )
+
+    code <- paste(lines, collapse = "; ")
+    args <- c("--vanilla", "-s", "-e", renv_shell_quote(code))
+    renv_system_exec(R(), args, action = "installing Biobase", quiet = TRUE)
+  })
 
   expect_true(renv_package_installed("BiocManager"))
   expect_true(renv_package_installed("BiocVersion"))
@@ -33,9 +48,6 @@ test_that("packages can be installed, restored from Bioconductor", {
   expect_true("BiocVersion" %in% names(records))
   expect_true("Biobase" %in% names(records))
 
-  if (!renv_platform_linux())
-    renv_scope_options(pkgType = .Platform$pkgType)
-
   remove("Biobase")
   restore()
   expect_true(renv_package_installed("Biobase"))
